@@ -28,11 +28,10 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // ---
-// Author: Frank H. Jernigan
 //
 // This file implements the Template class.  For information about
 // how to use this class, and to write the templates it takes as input,
-// see doc/howto.html
+// see the doc/ directory.
 
 #ifndef CTEMPLATE_TEMPLATE_H_
 #define CTEMPLATE_TEMPLATE_H_
@@ -45,7 +44,8 @@
 
 // We include this just so folks don't have to include both template.h
 // and template_dictionary.h, or template_namelist.h etc, to use the
-// template system; we don't actually use anything in these files ourselves.
+// template system; we don't actually use anything in these files
+// ourselves.
 #if 1
 #include <ctemplate/template_dictionary.h>
 #include <ctemplate/template_namelist.h>
@@ -57,12 +57,12 @@ class PerExpandData;
 }
 #endif
 
-
-
 namespace google_ctemplate_streamhtmlparser {
 class HtmlParser;
 }
 
+
+
 namespace ctemplate {
 
 // These free functions form the "simple" template API, and support
@@ -74,8 +74,8 @@ namespace ctemplate {
 // to create your own TemplateCache object, and work directly with
 // it.  See template_cache.h for details.
 
- const TemplateCache* default_template_cache();
- TemplateCache* mutable_default_template_cache();
+extern  const TemplateCache* default_template_cache();
+extern  TemplateCache* mutable_default_template_cache();
 
 
 // ---- EXPANDING A TEMPLATE -------
@@ -285,7 +285,8 @@ class  Template {
   static std::string template_root_directory() {
     return default_template_cache()->template_root_directory();
   }
-  static std::string FindTemplateFilename(const std::string& unresolved) {
+  static std::string FindTemplateFilename(
+      const std::string& unresolved) {
     return default_template_cache()->FindTemplateFilename(unresolved);
   }
   static void RemoveStringFromTemplateCache(const std::string& key) {
@@ -482,4 +483,5 @@ class  Template {
 
 }
 
+
 #endif // CTEMPLATE_TEMPLATE_H_
