@@ -48,6 +48,7 @@
 #include "base/arena-inl.h"
 #include "base/thread_annotations.h"
 #include "indented_writer.h"
+#include <ctemplate/find_ptr.h>
 #include <ctemplate/template_dictionary.h>
 #include <ctemplate/template_modifiers.h>
 #include "base/small_map.h"
@@ -59,8 +60,6 @@ using std::map;
 using std::pair;
 using std::make_pair;
 
-typedef long int64;   // used with SetIntValue
-
 _START_GOOGLE_NAMESPACE_
 
 // Guards the initialization of the global dictionary.
@@ -438,7 +437,7 @@ void TemplateDictionary::SetValueWithoutCopy(const TemplateString variable,
 }
 
 void TemplateDictionary::SetIntValue(const TemplateString variable,
-                                     int64 value) {
+                                     long value) {
   char buffer[64];   // big enough for any int
   int valuelen = snprintf(buffer, sizeof(buffer), "%ld", value);
   LazilyCreateDict(&variable_dict_);
@@ -447,9 +446,9 @@ void TemplateDictionary::SetIntValue(const TemplateString variable,
 
 void TemplateDictionary::SetFormattedValue(const TemplateString variable,
                                            const char* format, ...) {
-  char *scratch, *buffer;
+  char* buffer;
 
-  scratch = arena_->Alloc(1024);  // StringAppendV requires >=1024 bytes
+  char* scratch = arena_->Alloc(1024);  // StringAppendV requires >=1024 bytes
   va_list ap;
   va_start(ap, format);
   const int buflen = StringAppendV(scratch, &buffer, format, ap);
@@ -471,16 +470,15 @@ void TemplateDictionary::SetFormattedValue(const TemplateString variable,
 void TemplateDictionary::SetEscapedValue(TemplateString variable,
                                          TemplateString value,
                                          const TemplateModifier& escfn) {
-  string escaped_string(escfn(value.ptr_, value.length_));
-  SetValue(variable, escaped_string);
+  SetValue(variable, string(escfn(value.data(), value.size())));
 }
 
 void TemplateDictionary::SetEscapedFormattedValue(TemplateString variable,
                                                   const TemplateModifier& escfn,
                                                   const char* format, ...) {
-  char *scratch, *buffer;
+  char* buffer;
 
-  scratch = arena_->Alloc(1024);  // StringAppendV requires >=1024 bytes
+  char* scratch = arena_->Alloc(1024);  // StringAppendV requires >=1024 bytes
   va_list ap;
   va_start(ap, format);
   const int buflen = StringAppendV(scratch, &buffer, format, ap);
@@ -556,25 +554,21 @@ void TemplateDictionary::SetTemplateGlobalValueWithoutCopy(
     const TemplateString& dict_name, const TemplateString& sub_name,
     size_t index, const char* suffix) {
   char index_str[64];
-  snprintf(index_str, sizeof(index_str), "%"PRIuS, index);
+  snprintf(index_str, sizeof(index_str), "%" PRIuS, index);
   return (PrintableTemplateString(dict_name) + "/" +
           PrintableTemplateString(sub_name) + "#" + index_str + suffix);
 }
 
 TemplateDictionary* TemplateDictionary::AddSectionDictionary(
     const TemplateString section_name) {
-  DictVector* dicts = NULL;
   LazilyCreateDict(&section_dict_);
-  const SectionDict::iterator it = section_dict_->find(
-      section_name.GetGlobalId());
-  if (it == section_dict_->end()) {
+  DictVector* dicts = find_ptr2(*section_dict_, section_name.GetGlobalId());
+  if (!dicts) {
     dicts = CreateDictVector();
     // Since most lists will remain under 8 or 16 entries but will frequently
     // be more than four, this prevents copying from 1->2->4->8.
     dicts->reserve(8);
     HashInsert(section_dict_, section_name, dicts);
-  } else {
-    dicts = it->second;
   }
   assert(dicts != NULL);
   const string newname(CreateSubdictName(name_, section_name,
@@ -588,7 +582,7 @@ TemplateDictionary* TemplateDictionary::AddSectionDictionary(
 
 void TemplateDictionary::ShowSection(const TemplateString section_name) {
   LazilyCreateDict(&section_dict_);
-  if (section_dict_->find(section_name.GetGlobalId()) == section_dict_->end()) {
+  if (!section_dict_->count(section_name.GetGlobalId())) {
     TemplateDictionary* empty_dict = CreateTemplateSubdict(
         "empty dictionary", arena_, this, template_global_dict_owner_);
     DictVector* sub_dict = CreateDictVector();
@@ -643,15 +637,11 @@ void TemplateDictionary::SetEscapedValueAndShowSection(
 
 TemplateDictionary* TemplateDictionary::AddIncludeDictionary(
     const TemplateString include_name) {
-  DictVector* dicts = NULL;
   LazilyCreateDict(&include_dict_);
-  const IncludeDict::iterator it = include_dict_->find(
-      include_name.GetGlobalId());
-  if (it == include_dict_->end()) {
+  DictVector* dicts = find_ptr2(*include_dict_, include_name.GetGlobalId());
+  if (!dicts) {
     dicts = CreateDictVector();
     HashInsert(include_dict_, include_name, dicts);
-  } else {
-    dicts = it->second;
   }
   assert(dicts != NULL);
   const string newname(CreateSubdictName(name_, include_name,
@@ -871,7 +861,7 @@ class TemplateDictionary::DictionaryPrinter {
 
   string GetDictNum(size_t index, size_t size) const {
     char buf[64];   // big enough for two ints
-    snprintf(buf, sizeof(buf), "%"PRIuS" of %"PRIuS, index, size);
+    snprintf(buf, sizeof(buf), "%" PRIuS" of %" PRIuS, index, size);
     return buf;
   }
 
@@ -918,10 +908,8 @@ TemplateString TemplateDictionary::GetValue(
     const TemplateString& variable) const LOCKS_EXCLUDED(g_static_mutex) {
   for (const TemplateDictionary* d = this; d; d = d->parent_dict_) {
     if (d->variable_dict_) {
-      VariableDict::const_iterator it
-          = d->variable_dict_->find(variable.GetGlobalId());
-      if (it != d->variable_dict_->end())
-        return it->second;
+      if (const TemplateString* it = find_ptr(*d->variable_dict_, variable.GetGlobalId()))
+        return *it;
     }
   }
 
@@ -932,18 +920,15 @@ TemplateString TemplateDictionary::GetValue(
     const VariableDict* template_global_vars =
         template_global_dict_owner_->template_global_dict_->variable_dict_;
 
-    VariableDict::const_iterator it =
-        template_global_vars->find(variable.GetGlobalId());
-    if (it != template_global_vars->end())
-      return it->second;
+    if (const TemplateString* it = find_ptr(*template_global_vars, variable.GetGlobalId()))
+      return *it;
   }
 
   // No match in dict tree or template-global dict.  Last chance: global dict.
   {
     ReaderMutexLock ml(&g_static_mutex);
-    GlobalDict::const_iterator it = global_dict_->find(variable.GetGlobalId());
-    if (it != global_dict_->end())
-      return it->second;
+    if (const TemplateString* it = find_ptr(*global_dict_, variable.GetGlobalId()))
+      return *it;
     return *empty_string_;
   }
 }
@@ -951,7 +936,7 @@ TemplateString TemplateDictionary::GetValue(
 bool TemplateDictionary::IsHiddenSection(const TemplateString& name) const {
   for (const TemplateDictionary* d = this; d; d = d->parent_dict_) {
     if (d->section_dict_ &&
-        d->section_dict_->find(name.GetGlobalId()) != d->section_dict_->end())
+        d->section_dict_->count(name.GetGlobalId()))
       return false;
   }
   assert(template_global_dict_owner_ != NULL);
@@ -959,7 +944,7 @@ bool TemplateDictionary::IsHiddenSection(const TemplateString& name) const {
       template_global_dict_owner_->template_global_dict_->section_dict_) {
     SectionDict* sections =
         template_global_dict_owner_->template_global_dict_->section_dict_;
-    if (sections->find(name.GetGlobalId()) != sections->end()) {
+    if (sections->count(name.GetGlobalId())) {
       return false;
     }
   }
@@ -969,7 +954,7 @@ bool TemplateDictionary::IsHiddenSection(const TemplateString& name) const {
 bool TemplateDictionary::IsHiddenTemplate(const TemplateString& name) const {
   for (const TemplateDictionary* d = this; d; d = d->parent_dict_) {
     if (d->include_dict_ &&
-        d->include_dict_->find(name.GetGlobalId()) != d->include_dict_->end())
+        d->include_dict_->count(name.GetGlobalId()))
       return false;
   }
   return true;
@@ -979,10 +964,8 @@ const char *TemplateDictionary::GetIncludeTemplateName(
     const TemplateString& variable, int dictnum) const {
   for (const TemplateDictionary* d = this; d; d = d->parent_dict_) {
     if (d->include_dict_) {
-      IncludeDict::const_iterator it = d->include_dict_->find(
-          variable.GetGlobalId());
-      if (it != d->include_dict_->end()) {
-        TemplateDictionary* dict = (*it->second)[dictnum];
+      if (DictVector* it = find_ptr2(*d->include_dict_, variable.GetGlobalId())) {
+        TemplateDictionary* dict = (*it)[dictnum];
         return dict->filename_ ? dict->filename_ : "";   // map NULL to ""
       }
     }
@@ -1022,11 +1005,9 @@ TemplateDictionary::CreateTemplateIterator(
     const TemplateString& section_name) const {
   for (const TemplateDictionary* d = this; d; d = d->parent_dict_) {
     if (d->include_dict_) {
-      IncludeDict::const_iterator it = d->include_dict_->find(
-          section_name.GetGlobalId());
-      if (it != d->include_dict_->end()) {
+      if (DictVector* it = find_ptr2(*d->include_dict_, section_name.GetGlobalId())) {
         // Found it!  Return it as an Iterator
-        return MakeIterator(*it->second);
+        return MakeIterator(*it);
       }
     }
   }
@@ -1039,11 +1020,9 @@ TemplateDictionary::CreateSectionIterator(
     const TemplateString& section_name) const {
   for (const TemplateDictionary* d = this; d; d = d->parent_dict_) {
     if (d->section_dict_) {
-      SectionDict::const_iterator it = d->section_dict_->find(
-          section_name.GetGlobalId());
-      if (it != d->section_dict_->end()) {
+      if (const DictVector* it = find_ptr2(*d->section_dict_, section_name.GetGlobalId())) {
         // Found it!  Return it as an Iterator
-        return MakeIterator(*it->second);
+        return MakeIterator(*it);
       }
     }
   }
@@ -1052,11 +1031,8 @@ TemplateDictionary::CreateSectionIterator(
   const TemplateDictionary* template_global_dict =
       template_global_dict_owner_->template_global_dict_;
   if (template_global_dict && template_global_dict->section_dict_) {
-    SectionDict::const_iterator it =
-        template_global_dict->section_dict_->find(
-            section_name.GetGlobalId());
-    if (it != template_global_dict->section_dict_->end()) {
-      return MakeIterator(*it->second);
+    if (const DictVector* it = find_ptr2(*template_global_dict->section_dict_, section_name.GetGlobalId())) {
+      return MakeIterator(*it);
     }
   }
   assert("Call IsHiddenSection before GetDictionaries" && 0);
